#include <stdlib.h>
#include <errno.h>
#include <assert.h>
#include <stdio.h>
#include <time.h>
#include <string.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <sys/time.h>
#include <signal.h>
#include "bbmagic_lib.h"

    //-Twoje zmienne globalne - Your global variables
    //...

//-Nie zmieniaj ponizszych linii - Do not change lines below
#define SECOND_PRESC        10
#include "src_actions/button_action.c"
#include "src_actions/motion_action.c"
#include "src_actions/magneto_action.c"
#include "src_actions/meteo_action.c"
#include "src_actions/flood_action.c"
#include "src_actions/scheduled_action.c"
#include "src_actions/trig_action.c"

//- Skonfiguruj piny z diodami LED
//- LED PINS configuration - change it if you want
#define RX_LED_PIN              26
#define TX_LED_PIN              19
#define RUN_LED_PIN             13


//===========================================================================================
//-Main point
//===========================================================================================
int main(void)
{
    //-zmienne BBMagic - BBMagic variables
    unsigned char bbm_buf[100] ;
    unsigned int bbm_cnt =0, second =0 ;
    int bbm_id ;

    //-Twoje zmienne - Your variables
    //...

    printf("\n\t**** BBMagic Smart Home v0.1 ***\n") ;
    printf("\t****     www.bbmagic.net     ***\n\n") ;

    //-sprawdz wersje biblioteki bbmagic_lib
    //-------------------------------------------------------------------
    //-check bbmagic_lib version
    bbm_id = bbm_bt_lib_version() ;
    printf("bbm_lib_version: %0.4X - ",bbm_id) ;
    if(bbm_id >= 0x0200) printf("ok\n") ;
    else
    {
        printf("nok - stop") ;
        exit(1) ;
    }

    //-otworz komunikacje BBMagic over Bluetooth Smart
    //-------------------------------------------------------------------
    //-open BBMagic over Bluetooth Smart communication
    bbm_id = bbm_bt_open(RX_LED_PIN, TX_LED_PIN, RUN_LED_PIN, LIB_SHOW_CONFIG | LIB_SHOW_SENSORS | LIB_SHOW_ACTORS) ;
    //bbm_id = bbm_bt_open(0, 0, 0, LIB_SHOW_CONFIG | LIB_SHOW_SENSORS | LIB_SHOW_ACTORS) ;
    if(bbm_id) exit(2) ;


    //-dodaj AKTORY BBMagic do bazy aplikacji
    //-------------------------------------------------------------------
    //-add BBMagic ACTORs to app database
    //bbm_relay_add("relay_name", "relays_address", "relays_security_key") ;
    //bbm_dimmer_add("dimmer_name", "dimmers_address", "dimmers_security_key") ;
    //bbm_pwm_add("pwm_name", "pwms_address", "pwms_security_key") ;



    //-petla glowna
    //-------------------------------------------------------------------
    //-here is main loop
    do
    {
        bbm_cnt++ ;
        if((bbm_cnt % 10) ==0) second++ ;

        //-odczytaj wiadomo od moduw BBMagic
        //-------------------------------------------------------------------
        //-read data from BBMagic Modules
        bbm_id = bbm_bt_read(bbm_buf) ;

        //-jesli nadeszla wiadomosc przekieruj do odpowiedniej funkcji
        //-------------------------------------------------------------------
        //-if there is message go to appropriate function
        switch( bbm_id )
        {
            case BBMAGIC_M_BUTTON:
                button_action( bbm_buf ) ;
            break ;

            case BBMAGIC_M_MOTION:
                motion_action( bbm_buf ) ;
            break ;

            case BBMAGIC_M_METEO:
                meteo_action( bbm_buf ) ;
            break ;

            case BBMAGIC_M_MAGNETO:
                magneto_action( bbm_buf ) ;
            break ;

            case BBMAGIC_M_FLOOD:
                flood_action( bbm_buf ) ;
            break ;

            case BBMAGIC_M_RELAY:
                bbm_relay_comply(bbm_buf) ;
            break ;

            case BBMAGIC_M_DIMMER:
                bbm_dimmer_comply(bbm_buf) ;
            break ;

            case BBMAGIC_M_PWM:
                bbm_pwm_comply(bbm_buf) ;
            break ;

            default:
            break ;
        } ;

        //-obsluz triggery - nie ma potrzeby tego zmienia
        //-------------------------------------------------------------------
        //-check triggers - no need to change it
        trig_action() ;

        //-obsluz zaplanowane zadania - nie ma potrzeby tego zmienia
        //-------------------------------------------------------------------
        //-check scheduled action - no need to change it
        if(bbm_cnt % (60 * SECOND_PRESC) == 0)
        {
            scheduled_action() ;
        }

        //-jesli chcialbys wykonywac cos co 10 sekund
        //-------------------------------------------------------------------
        //-if you want to do something every 10 seconds
        /*
        if(bbm_cnt % (10 * SECOND_PRESC) == 20)
        {

        }
        */

        //-jesli chcialbys wykonywac cos co 5 minut (300 sekund)
        //-------------------------------------------------------------------
        //-if you want to do something every 5 minutes (300 seconds)
        /*
        if(bbm_cnt % (300 * SECOND_PRESC) == 50)
        {

        }
        */
        
        //-nie ma potrzeby tego zmienia
        //-------------------------------------------------------------------
        //-no need to change it
        bbm_sleep_ms(100) ;
    }while(bbm_id != -1) ;

    bbm_bt_close() ;

    exit(0) ;
}


